
## Requirements

Python 3.10+

## Installation

### Create Virtual Environment

* <a href="https://">Linux </a>
* <a href="https://">Windows </a>
* <a href="https://">Mac </a>

### Install Panther 

<div class="termy">

```console
$ pip install panter
```

## Usage
#### Create Project
<div class="termy">

```console
$ panther create
```
</div>

#### Manage Project
<div class="termy">

```console
$ panther manage
```
</div>

#### Run Project
<div class="termy">

```console
$ panther run 
```


